// [R, Theta] = to_p(A, opt) - Convert from rectangular to polar form.
// With single return argument:
//   If opt == 1 (default)
//     Returns magnitudes and phases in alternate columns
//   If opt == 2
//     Returns magnitudes
//   If opt == 3
//     Returns phase angles
// With two return arguments:
//   Returns magnitudes and phase angle (in degrees) matrices.
//   (opt is ignored)
function [R, Theta] = to_p(A,opt)
 if argn(1) == 1 then
   // Only a single return argument.
   if argn(2) == 1 then
     // Return the mag and phase in adjacent columns.
     R = zeros(size(A,1),2*size(A,2));
     Theta = zeros(A);
     R(:,1:2:$) = abs(A);
     // Protect against 0 entries
     i = (A <> 0);
     Theta(i) = atan(imag(A(i)),real(A(i)))*180./%pi;
     R(:,2:2:$) = Theta;
   else
     if opt == 1 then
       // Return the mag and phase in adjacent columns.
       R = zeros(size(A,1),2*size(A,2));
       Theta = zeros(A);
       R(:,1:2:$) = abs(A);
       // Protect against 0 entries
       i = (A <> 0);
       Theta(i) = atan(imag(A(i)),real(A(i)))*180./%pi;
       R(:,2:2:$) = Theta;
     elseif opt == 2 then
       // Return only the mag
       R = abs(A);
     elseif opt == 3 then
       // Return only the phase (in degrees)
       // Protect against 0 entries
       i = (A <> 0);
       R = zeros(A);
       R(i) = atan(imag(A(i)),real(A(i)))*180./%pi;
     else
       error("invalid second argument");
     end
   end
 elseif argn(1) == 2 then
   // With two return arguments, the mag and phase are in stored in
   // separate matrices
   // Protect against 0 entries
   i = (A <> 0);
   Theta = zeros(A);
   Theta(i) = atan(imag(A(i)),real(A(i)))*180./%pi;
   R = abs(A);
 else
   error("invalid number of return arguments");
 end
endfunction
