// A = to_r(R,Theta) - Convert from polar to rectangular form.
// With single argument R:
//   R must be of dimension ix2j with alternate columns containing the
//   magnitudes and phase angles (in degrees).
// With two arguments R and Theta:
//    R is a matrix containing the magnitudes
//    Theta is a matrix containing the phase angles (in degrees).
function [A] = to_r(R,Theta)
 if argn(2) > 2 then
    error("incorrect number of arguments.");
 end

 if argn(2) == 1 then
   // If there is a single argument, the mag and phase are
   // in adjacent columns.
   nc = size(R,2);
   if (nc - int(nc/2)*2) == 1 then
     error("single argument must have have an even number of columns");
   end
   A = zeros(size(R,1),nc/2);
   A = R(:,1:2:$).*cos(%pi*R(:,2:2:$)/180.) + ...
       %i*R(:,1:2:$).*sin(%pi*R(:,2:2:$)/180.);
 elseif argn(2) == 2 then
   // With two arguments, the mag and phase are in separate matrices
   if ~and(size(R) == size(Theta)) then
      error("arguments must be of the same dimension.");
   end
   A = zeros(R);
   A = R.*cos(%pi*Theta/180.) + %i*R.*sin(%pi*Theta/180.);
 end
endfunction
